@@ -4,8 +4,9 @@ from sqlalchemy import Column, BigInteger
 from sqlalchemy import Integer
 from vortex.Tuple import Tuple, addTupleType
 
-from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import \
-    ACIProcessorQueueTupleABC
+from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import (
+    ACIProcessorQueueTupleABC,
+)
 from peek_core_search._private.PluginNames import searchTuplePrefix
 from .DeclarativeBase import DeclarativeBase
 
@@ -13,10 +14,9 @@ logger = logging.getLogger(__name__)
 
 
 @addTupleType
-class SearchIndexCompilerQueue(Tuple, DeclarativeBase,
-                               ACIProcessorQueueTupleABC):
-    __tablename__ = 'SearchIndexCompilerQueue'
-    __tupleType__ = searchTuplePrefix + 'SearchIndexCompilerQueueTable'
+class SearchIndexCompilerQueue(Tuple, DeclarativeBase, ACIProcessorQueueTupleABC):
+    __tablename__ = "SearchIndexCompilerQueue"
+    __tupleType__ = searchTuplePrefix + "SearchIndexCompilerQueueTable"
 
     id = Column(BigInteger, primary_key=True, autoincrement=True)
     chunkKey = Column(Integer, primary_key=True)
