@@ -1,7 +1,8 @@
 import logging
 
-from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import \
-    ACIProcessorQueueTupleABC
+from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import (
+    ACIProcessorQueueTupleABC,
+)
 from peek_core_search._private.PluginNames import searchTuplePrefix
 from sqlalchemy import Column, BigInteger
 from sqlalchemy import Integer
@@ -13,10 +14,9 @@ logger = logging.getLogger(__name__)
 
 
 @addTupleType
-class SearchObjectCompilerQueue(Tuple, DeclarativeBase,
-                                ACIProcessorQueueTupleABC):
-    __tablename__ = 'SearchObjectCompilerQueue'
-    __tupleType__ = searchTuplePrefix + 'SearchObjectCompilerQueueTable'
+class SearchObjectCompilerQueue(Tuple, DeclarativeBase, ACIProcessorQueueTupleABC):
+    __tablename__ = "SearchObjectCompilerQueue"
+    __tupleType__ = searchTuplePrefix + "SearchObjectCompilerQueueTable"
 
     id = Column(BigInteger, primary_key=True, autoincrement=True)
     chunkKey = Column(Integer, primary_key=True)
