@@ -1,21 +1,24 @@
 from typing import List, Dict
 
 from peek_core_search._private.PluginNames import searchTuplePrefix
-from peek_core_search._private.storage.SearchObjectTypeTuple import \
-    SearchObjectTypeTuple
-from peek_core_search.tuples.ImportSearchObjectRouteTuple import \
-    ImportSearchObjectRouteTuple
+from peek_core_search._private.storage.SearchObjectTypeTuple import (
+    SearchObjectTypeTuple,
+)
+from peek_core_search.tuples.ImportSearchObjectRouteTuple import (
+    ImportSearchObjectRouteTuple,
+)
 from vortex.Tuple import Tuple, addTupleType, TupleField
 
 
 @addTupleType
 class SearchResultObjectTuple(Tuple):
-    """ Import Search Object
+    """Import Search Object
 
     This tuple is used by other plugins to load objects into the search index.
 
     """
-    __tupleType__ = searchTuplePrefix + 'SearchResultObjectTuple'
+
+    __tupleType__ = searchTuplePrefix + "SearchResultObjectTuple"
 
     # The id of the object this search result is for
     id: int = TupleField()
